#include "defsc573.h"
#include "cdefsc573.h"
#include "stdint.h"
#include "stdio.h"
#include "stdlib.h"

#define DMC0_START_ADDRESS 0x80000000
#define DMC1_START_ADDRESS 0xC0000000

#define BUFF_SIZE 1024

int Test_DMC_Basic(unsigned int start_address);

/*************************************************************************************************************************
									Enum definitions
**************************************************************************************************************************/
//Use these to specifiy whether core/DMA access is required (e.g. for sweep test)
enum ACCESS_TYPE
{
	CORE_ACCESS,
	DMA_ACCESS
};

//Use these to specify the word size (8/16/32/64 bits) requied e.g. for sweep test
enum WORD_SIZE
{
	WORD_SIZE_8BITS,
	WORD_SIZE_16BITS,
	WORD_SIZE_32BITS,
	WORD_SIZE_64BITS,
	WORD_SIZE_32BYTES
};

//Use these to specify the data pattern in the sweep test
enum PATTERN_TPYE
{
	ALL_ZEROS,
	ALL_ONES,
	ALL_A,
	ALL_5,
	INCREMENTAL_VALUES,
	RANDOM_VALUES,
	ALL_BITS_TOGGLING,
};

//Use these to specify the memory type in the sweep test
enum MEM_TEST_TYPE
{
	MEMTEST_L1,
	MEMTEST_L2,
	MEMTEST_DDR2,
	MEMTEST_DDR3,
	MEMTEST_LPDDR,
};

/*************************************************************************************************************************
									MACROs
************************************************************************************************************************/
//This macro can be used to configure an MDMA stream by providing the source and destination DMA channel details
#define MDMA_CONFIG(S_MDMA_CHANNEL,S_CFG, S_ADDRSTART, S_MOD, S_COUNT,D_MDMA_CHANNEL,D_CFG, D_ADDRSTART, D_MOD, D_COUNT)\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG = S_CFG;\
		*pREG_DMA##S_MDMA_CHANNEL##_ADDRSTART = S_ADDRSTART;\
		*pREG_DMA##S_MDMA_CHANNEL##_XCNT = S_COUNT;\
		*pREG_DMA##S_MDMA_CHANNEL##_XMOD = S_MOD;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG = D_CFG;\
		*pREG_DMA##D_MDMA_CHANNEL##_ADDRSTART = D_ADDRSTART;\
		*pREG_DMA##D_MDMA_CHANNEL##_XCNT = D_COUNT;\
		*pREG_DMA##D_MDMA_CHANNEL##_XMOD = D_MOD;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG |= 0x1;\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG |= 0x1;

//Macro to wait for DMA done
#define WAIT_FOR_DMADONE(DMA_CHANNEL)\
		while(!(*pREG_DMA##DMA_CHANNEL##_STAT & ENUM_DMA_STAT_IRQDONE));

//Macro to disable MDMA channels
#define DISABLE_MDMA(S_MDMA_CHANNEL, D_MDMA_CHANNEL)\
		*pREG_DMA##S_MDMA_CHANNEL##_CFG = 0;\
		*pREG_DMA##D_MDMA_CHANNEL##_CFG = 0;

#define LSMDMA0_DDE8_ID 			102
#define LSMDMA0_DDE9_ID 			103

// Base addresses for Write Protection, Secure Peripheral and Secure Core
#define WP_BASE_ADDRESS  				(REG_SPU0_WP0)
#define SECURE_PERIPHERAL_BASE_ADDRESS  (REG_SPU0_SECUREP0)
#define SECURE_CORE_BASE_ADDRESS 		(REG_SPU0_SECUREC0)

// Secure peripheral Control
#define SECUREP_MSEC_EN 		((1 << BITP_SPU_SECUREP_MSEC) & BITM_SPU_SECUREP_MSEC)
#define SECUREP_SSEC_EN 		((1 << BITP_SPU_SECUREP_SSEC) & BITM_SPU_SECUREP_SSEC)
#define SECUREP_MSEC_DIS 		((0 << BITP_SPU_SECUREP_MSEC) & BITM_SPU_SECUREP_MSEC)
#define SECUREP_SSEC_DIS 		((0 << BITP_SPU_SECUREP_SSEC) & BITM_SPU_SECUREP_SSEC)

/*************************************************************************************************************************
									Function Declarations
**************************************************************************************************************************/
uint32_t Memory_Sweep_Test_8Bits(uint8_t* uiMUTStartAdd, uint32_t uiCount, uint32_t uiAccessType, uint32_t uiDataPattern, uint8_t* uiSrcBuffAdd, uint8_t* uiDestBuffAdd, uint32_t uiBuffSize);
uint32_t Memory_Sweep_Test_16Bits(uint16_t* uiMUTStartAdd, uint32_t uiCount, uint32_t uiAccessType, uint32_t uiDataPattern, uint16_t* uiSrcBuffAdd, uint16_t* uiDestBuffAdd, uint32_t uiBuffSize);
uint32_t Memory_Sweep_Test_32Bits(uint32_t* uiMUTStartAdd, uint32_t uiCount, uint32_t uiAccessType, uint32_t uiDataPattern, uint32_t* uiSrcBuffAdd, uint32_t* uiDestBuffAdd, uint32_t uiBuffSize);
uint32_t Memory_Sweep_Test_64Bits(uint64_t* uiMUTStartAdd, uint32_t uiCount, uint32_t uiAccessType, uint32_t uiDataPattern, uint64_t* uiSrcBuffAdd, uint64_t* uiDestBuffAdd, uint32_t uiBuffSize);
uint32_t Memory_Sweep_Test(uint32_t uiMUTStartAdd, uint32_t uiCount);
void SPU_SecurePeripheral_AccessConfig(int iPeripheralID, bool bMaster, bool bSlave );
void Print_DMC_Register_Contents(uint32_t dmc_no);

