#include "DMCInit_Debug.h"

#pragma align 32
uint64_t uiSrcBuff[256*4];

#pragma align 32
uint64_t uiDestBuff[256*4];

void Print_DMC_Register_Contents(uint32_t dmc_no)
{
#ifdef __ADSPSC5xx__
	volatile int *pDMC;
	if(dmc_no==0)
	{
		//DMC Controller registers
		printf("\nDMC0_CTL = 0x%0x",*pREG_DMC0_CTL);
		printf("\nDMC0_CFG = 0x%0x",*pREG_DMC0_CFG);
		printf("\nDMC0_TR0 = 0x%0x",*pREG_DMC0_TR0);
		printf("\nDMC0_TR1 = 0x%0x",*pREG_DMC0_TR1);
		printf("\nDMC0_TR2 = 0x%0x",*pREG_DMC0_TR2);
		printf("\nDMC0_MR = 0x%0x",*pREG_DMC0_MR);
		printf("\nDMC0_MR1 = 0x%0x",*pREG_DMC0_MR1);
		printf("\nDMC0_MR2 = 0x%0x",*pREG_DMC0_MR2);
		printf("\nDMC0_DCLLCTL = 0x%0x",*pREG_DMC0_DLLCTL);

		//DMC PHY registers
		pDMC=(volatile int*)0x31071000;
		printf("\nDMC0_PHY_CTL0 = 0x%0x",*pDMC);pDMC++;
		printf("\nDMC0_PHY_CTL1 = 0x%0x",*pDMC);pDMC++;
		printf("\nDMC0_PHY_CTL2 = 0x%0x",*pDMC);pDMC++;
		printf("\nDMC0_PHY_CTL3 = 0x%0x",*pDMC);pDMC++;
		printf("\nDMC0_PHY_CTL4 = 0x%0x",*pDMC);pDMC++;
		pDMC++;
		pDMC++;
		pDMC++;
		pDMC++;
		pDMC++;
		pDMC++;
		pDMC++;
		pDMC++;
		printf("\nDMC0_CAL_PADCTL0 = 0x%0x",*pDMC);pDMC++;
		pDMC++;
		printf("\nDMC0_CAL_PADCTL2 = 0x%0x",*pDMC);pDMC++;
		pDMC++;
	}

#ifdef __ADSPSC58x__
	else if(dmc_no==1)
	{
		//DMC Controller registers
		printf("\nDMC1_CTL = 0x%0x",*pREG_DMC1_CTL);
		printf("\nDMC1_CFG = 0x%0x",*pREG_DMC1_CFG);
		printf("\nDMC1_TR0 = 0x%0x",*pREG_DMC1_TR0);
		printf("\nDMC1_TR1 = 0x%0x",*pREG_DMC1_TR1);
		printf("\nDMC1_TR2 = 0x%0x",*pREG_DMC1_TR2);
		printf("\nDMC1_MR = 0x%0x",*pREG_DMC1_MR);
		printf("\nDMC1_MR1 = 0x%0x",*pREG_DMC1_MR1);
		printf("\nDMC1_MR2 = 0x%0x",*pREG_DMC1_MR2);
		printf("\nDMC1_DCLLCTL = 0x%0x",*pREG_DMC1_DLLCTL);

		//DMC PHY registers
		pDMC=(volatile int*)0x31074000;
		printf("\nDMC1_PHY_CTL0 = 0x%0x",*pDMC);pDMC++;
		printf("\nDMC1_PHY_CTL1 = 0x%0x",*pDMC);pDMC++;
		printf("\nDMC1_PHY_CTL2 = 0x%0x",*pDMC);pDMC++;
		printf("\nDMC1_PHY_CTL3 = 0x%0x",*pDMC);pDMC++;
		printf("\nDMC1_PHY_CTL4 = 0x%0x",*pDMC);pDMC++;
		pDMC++;
		pDMC++;
		pDMC++;
		pDMC++;
		pDMC++;
		pDMC++;
		pDMC++;
		pDMC++;
		printf("\nDMC1_CAL_PADCTL0 = 0x%0x",*pDMC);pDMC++;
		pDMC++;
		printf("\nDMC1_CAL_PADCTL2 = 0x%0x",*pDMC);pDMC++;
		pDMC++;
	}
#endif

#endif

}

/**************************************************************************************************************************
	Function name	:  Memory_Sweep_Test_8Bits
    Description		:  This function can be used to perform a memory sweep test for 8 bit accesses
	Arguments		:	Parameter					 |	Description		 							| Valid values
						uiMUTStartAdd				 |  Start address of the memory under test 		| 8 bit aligned address
						uiCount						 |  Total number of words to be swept			| unsigned int 32 bit
						uiAccessType				 |  Type of access (core/DMA)					| 0=core, 1= DMA
						uiDataPattern				 |  Type of pattern								| 0=all zeros, 1= all ones,2=all A's,
																									  3= all 5's, 4=incremental, 5 =random
						sBuffAdd			     	 |  Source buffer start address for testing 	| 8 bit aligned address
						uiDestBuffAdd				 |  Destination buffer start address for testing| 8 bit aligned address
						uiBuffSize					 |  Size of the test buffer						| unsigned int 32 bit
	Return value	:   0=for no failure, non-zero= number of failures.
**************************************************************************************************************************/
uint32_t Memory_Sweep_Test_8Bits(uint8_t* uiMUTStartAdd, uint32_t uiCount, uint32_t uiAccessType, uint32_t uiDataPattern, uint8_t* uiSrcBuffAdd, uint8_t* uiDestBuffAdd, uint32_t uiBuffSize)
{
	int i,j;

	uint8_t* pSrcBuff; uint8_t* pDestBuff; uint8_t* pMUTRead; uint8_t* pMUTWrite;

	uint32_t uiFailCount=0;

	pSrcBuff=(uint8_t*)uiSrcBuffAdd;

	uint32_t uiSourceMSIZE  = 	1;
	uint32_t uiDestMSIZE 	=	1;
	uint32_t uiSourceDMACFG = 	ENUM_DMA_CFG_MSIZE01|ENUM_DMA_CFG_PSIZE04;
	uint32_t uiDestDMACFG   =   BITM_DMA_CFG_WNR|ENUM_DMA_CFG_PSIZE04|ENUM_DMA_CFG_MSIZE01|ENUM_DMA_CFG_XCNT_INT;


	//Fill the source buffer with data based on the pattern type argument
	switch (uiDataPattern)
	{
			case ALL_ZEROS:
						printf("\n\nData pattern = All ZEROS");
						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0x0;
							pSrcBuff++;
						}
						break;

			case ALL_ONES:
						printf("\n\nData pattern = All ONEs");
						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0xFF;
							pSrcBuff++;
						}
						break;

			case ALL_A:
						printf("\n\nData pattern = All A");
						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0xAA;
							pSrcBuff++;
						}
						break;

			case ALL_5:
						printf("\n\nData pattern = All 5");
						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0x55;
							pSrcBuff++;
						}
						break;

			case INCREMENTAL_VALUES:
						printf("\n\nData pattern = INCREMENTAL");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=(uint8_t)i;
							pSrcBuff++;
						}
						break;

			case RANDOM_VALUES:
						printf("\n\nData pattern = RANDOM");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=(uint8_t)(rand()%0xFF);
							 pSrcBuff++;
						}
						break;

			case ALL_BITS_TOGGLING:
						printf("\n\nData pattern = ALL_BITS_TOGGLING");

						for(i=0;i<uiBuffSize/4;i++)
						{
							*pSrcBuff=0xFF; pSrcBuff++;
							*pSrcBuff=0xFF; pSrcBuff++;
							*pSrcBuff=0; pSrcBuff++;
							*pSrcBuff=0; pSrcBuff++;
						}
						break;
	};

	//Initialize pointers
	pMUTRead=uiMUTStartAdd;
	pMUTWrite=uiMUTStartAdd;

	//Now perform the test
	for(i=0;i<uiCount;i=i+uiBuffSize)
	{
		pSrcBuff=uiSrcBuffAdd;
		pDestBuff=uiDestBuffAdd;

		if(uiAccessType==CORE_ACCESS)
		{
			//Perform core write accesses to transfer data from source buffer to the target memory location under test
			for(j=0;j<uiBuffSize;j++)
			{
				*pMUTWrite=*pSrcBuff;
				pMUTWrite++;
				pSrcBuff++;

			}
		}
		else if(uiAccessType==DMA_ACCESS)
		{
			//Perform DMA write accesses to transfer data from source buffer to the target memory location under test
			MDMA_CONFIG(8,uiSourceDMACFG, ((void*)((int)pSrcBuff|0x28000000)), uiSourceMSIZE, uiBuffSize,9,uiDestDMACFG, pMUTWrite, uiDestMSIZE, uiBuffSize);
			WAIT_FOR_DMADONE(9);
			DISABLE_MDMA(8,9);

			//Increment the write pointer
			pMUTWrite+=uiBuffSize;
		}

		if(uiAccessType==CORE_ACCESS)
		{
			//Perform core read accesses to transfer data from the memory location under test and to the dest buffer
			for(j=0;j<uiBuffSize;j++)
			{
				*pDestBuff=*pMUTRead;
				pMUTRead++;
				pDestBuff++;

			}
		}

		else if(uiAccessType==DMA_ACCESS)
		{
			//Perform DMA read accesses to transfer data from the memory location under test and to the dest buffer
			MDMA_CONFIG(8,uiSourceDMACFG, pMUTRead, uiSourceMSIZE, uiBuffSize,9,uiDestDMACFG, (void*)(((int)pDestBuff|0x28000000)), uiDestMSIZE, uiBuffSize);
			WAIT_FOR_DMADONE(9);
			DISABLE_MDMA(8,9);

			//Increment the read pointer
			pMUTRead+=uiBuffSize;
		}

		//Re-initialize the source and dest buffer pointers
		pSrcBuff=uiSrcBuffAdd;
		pDestBuff=uiDestBuffAdd;

		//Compare source and destination buffers for verification
		for(j=0;j<uiBuffSize;j++)
		{
			//If match does not occur, increment the failure count
			if(*pSrcBuff!=*pDestBuff)
			{
				uiFailCount++;
		//		printf("\nFailure at DMC address=0x%x, expected data=0x%x, read data=0x%x\n", (pMUTRead-uiBuffSize+j), *pSrcBuff, *pDestBuff);

			}
			pSrcBuff++;
			pDestBuff++;
		}
	}
	if(uiFailCount==0)
	{
		printf("\nTest Passed...");
	}
	else
	{
		printf("\nTest Failed...");
	}
	return uiFailCount;
}
/**************************************************************************************************************************
	Function name	:  Memory_Sweep_Test_16Bits
    Description		:  This function can be used to perform a memory sweep test for 16 bit accesses
	Arguments		:	Parameter					 |	Description		 							| Valid values
						uiMUTStartAdd				 |  Start address of the memory under test 		| 16 bit aligned address
						uiCount						 |  Total number of words to be swept			| unsigned int 32 bit
						uiAccessType				 |  Type of access (core/DMA)					| 0=core, 1= DMA
						uiDataPattern				 |  Type of pattern								| 0=all zeros, 1= all ones,2=all A's,
																									  3= all 5's, 4=incremental, 5 =random
						sBuffAdd			     	 |  Source buffer start address for testing 	| 16 bit aligned address
						uiDestBuffAdd				 |  Destination buffer start address for testing| 16 bit aligned address
						uiBuffSize					 |  Size of the test buffer						| unsigned int 32 bit
	Return value	:   0=for no failure, non-zero= number of failures.
**************************************************************************************************************************/
uint32_t Memory_Sweep_Test_16Bits(uint16_t* uiMUTStartAdd, uint32_t uiCount, uint32_t uiAccessType, uint32_t uiDataPattern, uint16_t* uiSrcBuffAdd, uint16_t* uiDestBuffAdd, uint32_t uiBuffSize)
{
	int i,j;

	uint16_t* pSrcBuff; uint16_t* pDestBuff; uint16_t* pMUTRead; uint16_t* pMUTWrite;

	uint32_t uiFailCount=0;

	pSrcBuff=(uint16_t*)uiSrcBuffAdd;

	uint32_t uiSourceMSIZE  = 	2;
	uint32_t uiDestMSIZE 	=	2;
	uint32_t uiSourceDMACFG = 	ENUM_DMA_CFG_MSIZE02|ENUM_DMA_CFG_PSIZE04;
	uint32_t uiDestDMACFG   =   BITM_DMA_CFG_WNR|ENUM_DMA_CFG_PSIZE04|ENUM_DMA_CFG_MSIZE02|ENUM_DMA_CFG_XCNT_INT;


	//Fill the source buffer with data based on the pattern type argument
	switch (uiDataPattern)
	{
			case ALL_ZEROS:
						printf("\n\nData pattern = All ZEROS");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0x0000;
							pSrcBuff++;
						}
						break;

			case ALL_ONES:
						printf("\n\nData pattern = All ONEs");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0xFFFF;
							pSrcBuff++;
						}
						break;

			case ALL_A:
						printf("\n\nData pattern = All A");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0xAAAA;
							pSrcBuff++;
						}
						break;

			case ALL_5:
						printf("\n\nData pattern = All 5");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0x5555;
							pSrcBuff++;
						}
						break;

			case INCREMENTAL_VALUES:

						printf("\n\nData pattern = INCREMENTAL");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=(uint16_t)i;
							pSrcBuff++;
						}
						break;

			case RANDOM_VALUES:

						printf("\n\nData pattern = RANDOM");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=(uint16_t)(rand()%0xFFFF);
							 pSrcBuff++;
						}
						break;

			case ALL_BITS_TOGGLING:
						printf("\n\nData pattern = ALL_BITS_TOGGLING");

						for(i=0;i<uiBuffSize/2;i++)
						{
							*pSrcBuff=0xFFFF; pSrcBuff++;
							*pSrcBuff=0x0000; pSrcBuff++;
						}
						break;

	};

	//Initialize pointers
	pMUTRead=uiMUTStartAdd;
	pMUTWrite=uiMUTStartAdd;

	//Now perform the test
	for(i=0;i<uiCount;i=i+uiBuffSize)
	{
		pSrcBuff=uiSrcBuffAdd;
		pDestBuff=uiDestBuffAdd;

		if(uiAccessType==CORE_ACCESS)
		{
			//Perform core write accesses to transfer data from source buffer to the target memory location under test
			for(j=0;j<uiBuffSize;j++)
			{
				*pMUTWrite=*pSrcBuff;
				pMUTWrite++;
				pSrcBuff++;

			}
		}
		else if(uiAccessType==DMA_ACCESS)
		{
			//Perform DMA write accesses to transfer data from source buffer to the target memory location under test
			MDMA_CONFIG(8,uiSourceDMACFG, ((void*)((int)pSrcBuff|0x28000000)), uiSourceMSIZE, uiBuffSize,9,uiDestDMACFG, pMUTWrite, uiDestMSIZE, uiBuffSize);
			WAIT_FOR_DMADONE(9);
			DISABLE_MDMA(8,9);

			//Increment the write pointer
			pMUTWrite+=uiBuffSize;
		}

		if(uiAccessType==CORE_ACCESS)
		{
			//Perform core read accesses to transfer data from the memory location under test and to the dest buffer
			for(j=0;j<uiBuffSize;j++)
			{
				*pDestBuff=*pMUTRead;
				pMUTRead++;
				pDestBuff++;

			}
		}

		else if(uiAccessType==DMA_ACCESS)
		{
			//Perform DMA read accesses to transfer data from the memory location under test and to the dest buffer
			MDMA_CONFIG(8,uiSourceDMACFG, pMUTRead, uiSourceMSIZE, uiBuffSize,9,uiDestDMACFG, (void*)(((int)pDestBuff|0x28000000)), uiDestMSIZE, uiBuffSize);
			WAIT_FOR_DMADONE(9);
			DISABLE_MDMA(8,9);

			//Increment the read pointer
			pMUTRead+=uiBuffSize;
		}

		//Re-initialize the source and dest buffer pointers
		pSrcBuff=uiSrcBuffAdd;
		pDestBuff=uiDestBuffAdd;

		//Compare source and destination buffers for verification
		for(j=0;j<uiBuffSize;j++)
		{
			//If match does not occur, increment the failure count
			if(*pSrcBuff!=*pDestBuff)
			{
				uiFailCount++;
			//	printf("\nFailure at DMC address=0x%x, expected data=0x%x, read data=0x%x\n", (pMUTRead-uiBuffSize+j), *pSrcBuff, *pDestBuff);
			}
			pSrcBuff++;
			pDestBuff++;
		}
	}
	if(uiFailCount==0)
	{
		printf("\nTest Passed...");
	}
	else
	{
		printf("\nTest Failed...");
	}
	return uiFailCount;
}
/**************************************************************************************************************************
	Function name	:  Memory_Sweep_Test_32Bits
    Description		:  This function can be used to perform a memory sweep test for 32 bit accesses
	Arguments		:	Parameter					 |	Description		 							| Valid values
						uiMUTStartAdd				 |  Start address of the memory under test 		| 32 bit aligned address
						uiCount						 |  Total number of words to be swept			| unsigned int 32 bit
						uiAccessType				 |  Type of access (core/DMA)					| 0=core, 1= DMA
						uiDataPattern				 |  Type of pattern								| 0=all zeros, 1= all ones,2=all A's,
																									  3= all 5's, 4=incremental, 5 =random
						sBuffAdd			     	 |  Source buffer start address for testing 	| 32 bit aligned address
						uiDestBuffAdd				 |  Destination buffer start address for testing| 32 bit aligned address
						uiBuffSize					 |  Size of the test buffer						| unsigned int 32 bit
	Return value	:   0=for no failure, non-zero= number of failures.
**************************************************************************************************************************/
uint32_t Memory_Sweep_Test_32Bits(uint32_t* uiMUTStartAdd, uint32_t uiCount, uint32_t uiAccessType, uint32_t uiDataPattern, uint32_t* uiSrcBuffAdd, uint32_t* uiDestBuffAdd, uint32_t uiBuffSize)
{
	int i,j;

	uint32_t* pSrcBuff; uint32_t* pDestBuff; uint32_t* pMUTRead; uint32_t* pMUTWrite;

	uint32_t uiFailCount=0;

	pSrcBuff=(uint32_t*)uiSrcBuffAdd;

	uint32_t uiSourceMSIZE  = 	4;
	uint32_t uiDestMSIZE 	=	4;
	uint32_t uiSourceDMACFG = 	ENUM_DMA_CFG_MSIZE04|ENUM_DMA_CFG_PSIZE04;
	uint32_t uiDestDMACFG   =   BITM_DMA_CFG_WNR|ENUM_DMA_CFG_PSIZE04|ENUM_DMA_CFG_MSIZE04|ENUM_DMA_CFG_XCNT_INT;


	//Fill the source buffer with data based on the pattern type argument
	switch (uiDataPattern)
	{
			case ALL_ZEROS:
						printf("\n\nData pattern = All ZEROS");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0x00000000;
							pSrcBuff++;
						}
						break;

			case ALL_ONES:
						printf("\n\nData pattern = All ONEs");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0xFFFFFFFF;
							pSrcBuff++;
						}
						break;

			case ALL_A:
						printf("\n\nData pattern = All A");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0xAAAAAAAA;
							pSrcBuff++;
						}
						break;

			case ALL_5:
						printf("\n\nData pattern = All 5");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0x55555555;
							pSrcBuff++;
						}
						break;

			case INCREMENTAL_VALUES:
						printf("\n\nData pattern = INCREMENTAL");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=(uint32_t)i;
							pSrcBuff++;
						}
						break;

			case RANDOM_VALUES:
						printf("\n\nData pattern = RANDOM");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=(uint32_t)(rand()%0xFFFFFFFF);
							 pSrcBuff++;
						}
						break;

			case ALL_BITS_TOGGLING:
						printf("\n\nData pattern = ALL_BITS_TOGGLING");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0xFFFF0000; pSrcBuff++;
						}
						break;

	};

	//Initialize pointers
	pMUTRead=uiMUTStartAdd;
	pMUTWrite=uiMUTStartAdd;

	//Now perform the test
	for(i=0;i<uiCount;i=i+uiBuffSize)
	{
		pSrcBuff=uiSrcBuffAdd;
		pDestBuff=uiDestBuffAdd;

		if(uiAccessType==CORE_ACCESS)
		{
			//Perform core write accesses to transfer data from source buffer to the target memory location under test
			for(j=0;j<uiBuffSize;j++)
			{
				*pMUTWrite=*pSrcBuff;
				pMUTWrite++;
				pSrcBuff++;

			}
		}
		else if(uiAccessType==DMA_ACCESS)
		{
			//Perform DMA write accesses to transfer data from source buffer to the target memory location under test
			MDMA_CONFIG(8,uiSourceDMACFG, ((void*)((int)pSrcBuff|0x28000000)), uiSourceMSIZE, uiBuffSize,9,uiDestDMACFG, pMUTWrite, uiDestMSIZE, uiBuffSize);
			WAIT_FOR_DMADONE(9);
			DISABLE_MDMA(8,9);

			//Increment the write pointer
			pMUTWrite+=uiBuffSize;
		}

		if(uiAccessType==CORE_ACCESS)
		{
			//Perform core read accesses to transfer data from the memory location under test and to the dest buffer
			for(j=0;j<uiBuffSize;j++)
			{
				*pDestBuff=*pMUTRead;
				pMUTRead++;
				pDestBuff++;

			}
		}

		else if(uiAccessType==DMA_ACCESS)
		{
			//Perform DMA read accesses to transfer data from the memory location under test and to the dest buffer
			MDMA_CONFIG(8,uiSourceDMACFG, pMUTRead, uiSourceMSIZE, uiBuffSize,9,uiDestDMACFG, (void*)(((int)pDestBuff|0x28000000)), uiDestMSIZE, uiBuffSize);
			WAIT_FOR_DMADONE(9);
			DISABLE_MDMA(8,9);

			//Increment the read pointer
			pMUTRead+=uiBuffSize;
		}

		//Re-initialize the source and dest buffer pointers
		pSrcBuff=uiSrcBuffAdd;
		pDestBuff=uiDestBuffAdd;

		//Compare source and destination buffers for verification
		for(j=0;j<uiBuffSize;j++)
		{
			//If match does not occur, increment the failure count
			if(*pSrcBuff!=*pDestBuff)
			{
				uiFailCount++;
			//	printf("\nFailure at DMC address=0x%x, expected data=0x%x, read data=0x%x\n", (pMUTRead-uiBuffSize+j), *pSrcBuff, *pDestBuff);

			}
			pSrcBuff++;
			pDestBuff++;
		}
	}
	if(uiFailCount==0)
	{
		printf("\nTest Passed...");
	}
	else
	{
		printf("\nTest Failed...");
	}
	return uiFailCount;
}
/**************************************************************************************************************************
	Function name	:  Memory_Sweep_Test_64Bits
    Description		:  This function can be used to perform a memory sweep test for 64 bit accesses
	Arguments		:	Parameter					 |	Description		 							| Valid values
						uiMUTStartAdd				 |  Start address of the memory under test 		| 64 bit aligned address
						uiCount						 |  Total number of words to be swept			| unsigned int 32 bit
						uiAccessType				 |  Type of access (core/DMA)					| 0=core, 1= DMA
						uiDataPattern				 |  Type of pattern								| 0=all zeros, 1= all ones,2=all A's,
																									  3= all 5's, 4=incremental, 5 =random
						sBuffAdd			     	 |  Source buffer start address for testing 	| 64 bit aligned address
						uiDestBuffAdd				 |  Destination buffer start address for testing| 64 bit aligned address
						uiBuffSize					 |  Size of the test buffer						| unsigned int 32 bit
	Return value	:   0=for no failure, non-zero= number of failures.
**************************************************************************************************************************/
uint32_t Memory_Sweep_Test_64Bits(uint64_t* uiMUTStartAdd, uint32_t uiCount, uint32_t uiAccessType, uint32_t uiDataPattern, uint64_t* uiSrcBuffAdd, uint64_t* uiDestBuffAdd, uint32_t uiBuffSize)
{
	int i,j;

	uint64_t* pSrcBuff; uint64_t* pDestBuff; uint64_t* pMUTRead; uint64_t* pMUTWrite;

	uint32_t uiFailCount=0;

	pSrcBuff=(uint64_t*)uiSrcBuffAdd;

	uint32_t uiSourceMSIZE  = 	8;
	uint32_t uiDestMSIZE 	=	8;
	uint32_t uiSourceDMACFG = 	ENUM_DMA_CFG_MSIZE08|ENUM_DMA_CFG_PSIZE04;
	uint32_t uiDestDMACFG   =   BITM_DMA_CFG_WNR|ENUM_DMA_CFG_PSIZE04|ENUM_DMA_CFG_MSIZE08|ENUM_DMA_CFG_XCNT_INT;


	//Fill the source buffer with data based on the pattern type argument
	switch (uiDataPattern)
	{
			case ALL_ZEROS:
						printf("\n\nData pattern = All ZEROS");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0x0000000000000000;
							pSrcBuff++;
						}
						break;

			case ALL_ONES:
						printf("\n\nData pattern = All ONEs");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0xFFFFFFFFFFFFFFFF;
							pSrcBuff++;
						}
						break;

			case ALL_A:
						printf("\n\nData pattern = All A");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0xAAAAAAAAAAAAAAAA;
							pSrcBuff++;
						}
						break;

			case ALL_5:
						printf("\n\nData pattern = All 5");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0x5555555555555555;
							pSrcBuff++;
						}
						break;

			case INCREMENTAL_VALUES:
						printf("\n\nData pattern = INCREMENTAL");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=(uint64_t)i;
							pSrcBuff++;
						}
						break;

			case RANDOM_VALUES:
						printf("\n\nData pattern = RANDOM");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=(uint64_t)(rand()%0xFFFFFFFFFFFFFFFF);
							 pSrcBuff++;
						}
						break;

			case ALL_BITS_TOGGLING:
						printf("\n\nData pattern = ALL_BITS_TOGGLING");

						for(i=0;i<uiBuffSize;i++)
						{
							*pSrcBuff=0xFFFF0000FFFF0000; pSrcBuff++;
						}
						break;

	};

	//Initialize pointers
	pMUTRead=uiMUTStartAdd;
	pMUTWrite=uiMUTStartAdd;

	//Now perform the test
	for(i=0;i<uiCount;i=i+uiBuffSize)
	{
		pSrcBuff=uiSrcBuffAdd;
		pDestBuff=uiDestBuffAdd;

		if(uiAccessType==CORE_ACCESS)
		{
			//Perform core write accesses to transfer data from source buffer to the target memory location under test
			for(j=0;j<uiBuffSize;j++)
			{
				*pMUTWrite=*pSrcBuff;
				pMUTWrite++;
				pSrcBuff++;

			}
		}
		else if(uiAccessType==DMA_ACCESS)
		{
			//Perform DMA write accesses to transfer data from source buffer to the target memory location under test
			MDMA_CONFIG(8,uiSourceDMACFG, ((void*)((int)pSrcBuff|0x28000000)), uiSourceMSIZE, uiBuffSize,9,uiDestDMACFG, pMUTWrite, uiDestMSIZE, uiBuffSize);
			WAIT_FOR_DMADONE(9);
			DISABLE_MDMA(8,9);

			//Increment the write pointer
			pMUTWrite+=uiBuffSize;
		}

		if(uiAccessType==CORE_ACCESS)
		{
			//Perform core read accesses to transfer data from the memory location under test and to the dest buffer
			for(j=0;j<uiBuffSize;j++)
			{
				*pDestBuff=*pMUTRead;
				pMUTRead++;
				pDestBuff++;

			}
		}

		else if(uiAccessType==DMA_ACCESS)
		{
			//Perform DMA read accesses to transfer data from the memory location under test and to the dest buffer
			MDMA_CONFIG(8,uiSourceDMACFG, pMUTRead, uiSourceMSIZE, uiBuffSize,9,uiDestDMACFG, (void*)(((int)pDestBuff|0x28000000)), uiDestMSIZE, uiBuffSize);
			WAIT_FOR_DMADONE(9);
			DISABLE_MDMA(8,9);

			//Increment the read pointer
			pMUTRead+=uiBuffSize;
		}

		//Re-initialize the source and dest buffer pointers
		pSrcBuff=uiSrcBuffAdd;
		pDestBuff=uiDestBuffAdd;

		uint64_t s1, d1;
		uint32_t* ps1; uint32_t* pd1; uint32_t* ps2; uint32_t* pd2;
		//Compare source and destination buffers for verification
		for(j=0;j<uiBuffSize;j++)
		{
			//If match does not occur, increment the failure count
			if(*pSrcBuff!=*pDestBuff)
			{
				uiFailCount++;
				s1=*pSrcBuff; d1=*pDestBuff;
				ps1=(uint32_t *)pSrcBuff; pd1=(uint32_t *)pDestBuff;
				ps2=ps1+1; pd2=pd1+1;
			}
			pSrcBuff++;
			pDestBuff++;
		}
	}
	if(uiFailCount==0)
	{
		printf("\nTest Passed...");
	}
	else
	{
		printf("\nTest Failed...");
	}
	return uiFailCount;
}

/**************************************************************************************************************************
	Function name	:  Memory_Sweep_Test_MSIZE32
    Description		:  This function can be used to perform a memory sweep test for DMA accesses with MSIZE=32
	Arguments		:	Parameter					 |	Description		 							| Valid values
						uiMUTStartAdd				 |  Start address of the memory under test 		| 64 bit aligned address
						uiCount						 |  Total number of words to be swept			| unsigned int 32 bit
						uiAccessType				 |  Type of access (core/DMA)					| 0=core, 1= DMA
						uiDataPattern				 |  Type of pattern								| 0=all zeros, 1= all ones,2=all A's,
																									  3= all 5's, 4=incremental, 5 =random
						sBuffAdd			     	 |  Source buffer start address for testing 	| 64 bit aligned address
						uiDestBuffAdd				 |  Destination buffer start address for testing| 64 bit aligned address
						uiBuffSize					 |  Size of the test buffer						| unsigned int 32 bit
	Return value	:   0=for no failure, non-zero= number of failures.
**************************************************************************************************************************/
uint32_t Memory_Sweep_Test_MSIZE32(uint64_t* uiMUTStartAdd, uint32_t uiCount, uint32_t uiAccessType, uint32_t uiDataPattern, uint64_t* uiSrcBuffAdd, uint64_t* uiDestBuffAdd, uint32_t uiBuffSize)
{
	int i,j;

	uint64_t* pSrcBuff; uint64_t* pDestBuff; uint64_t* pMUTRead; uint64_t* pMUTWrite;

	uint32_t uiFailCount=0;

	pSrcBuff=(uint64_t*)uiSrcBuffAdd;

	uint32_t uiSourceMSIZE  = 	32;
	uint32_t uiDestMSIZE 	=	32;
	uint32_t uiSourceDMACFG = 	ENUM_DMA_CFG_MSIZE32|ENUM_DMA_CFG_PSIZE04;
	uint32_t uiDestDMACFG   =   BITM_DMA_CFG_WNR|ENUM_DMA_CFG_PSIZE04|ENUM_DMA_CFG_MSIZE32|ENUM_DMA_CFG_XCNT_INT;


	//Fill the source buffer with data based on the pattern type argument
	switch (uiDataPattern)
	{
			case ALL_ZEROS:
					printf("\n\nData pattern = All ZEROS");

						for(i=0;i<uiBuffSize*4;i++)
						{
							*pSrcBuff=0x0000000000000000;
							pSrcBuff++;
						}
						break;

			case ALL_ONES:
						printf("\n\nData pattern = All ONEs");

						for(i=0;i<uiBuffSize*4;i++)
						{
							*pSrcBuff=0xFFFFFFFFFFFFFFFF;
							pSrcBuff++;
						}
						break;

			case ALL_A:
						printf("\n\nData pattern = All A");

						for(i=0;i<uiBuffSize*4;i++)
						{
							*pSrcBuff=0xAAAAAAAAAAAAAAAA;
							pSrcBuff++;
						}
						break;

			case ALL_5:
						printf("\n\nData pattern = All 5");

						for(i=0;i<uiBuffSize*4;i++)
						{
							*pSrcBuff=0x5555555555555555;
							pSrcBuff++;
						}
						break;

			case INCREMENTAL_VALUES:
						printf("\n\nData pattern = INCREMENTAL");

						for(i=0;i<uiBuffSize*4;i++)
						{
							*pSrcBuff=(uint64_t)i;
							pSrcBuff++;
						}
						break;

			case RANDOM_VALUES:
						printf("\n\nData pattern = RANDOM");

						for(i=0;i<uiBuffSize*4;i++)
						{
							*pSrcBuff=(uint64_t)(rand()%0xFFFFFFFFFFFFFFFF);
							 pSrcBuff++;
						}
						break;

			case ALL_BITS_TOGGLING:
						printf("\n\nData pattern = ALL_BITS_TOGGLING");

						for(i=0;i<uiBuffSize*4;i++)
						{
							*pSrcBuff=0xFFFF0000FFFF0000; pSrcBuff++;
						}
						break;

	};

	//Initialize pointers
	pMUTRead=uiMUTStartAdd;
	pMUTWrite=uiMUTStartAdd;

	//Now perform the test
	for(i=0;i<uiCount;i=i+uiBuffSize)
	{
		pSrcBuff=uiSrcBuffAdd;
		pDestBuff=uiDestBuffAdd;

		//Perform DMA write accesses to transfer data from source buffer to the target memory location under test
		MDMA_CONFIG(8,uiSourceDMACFG, ((void*)((int)pSrcBuff|0x28000000)), uiSourceMSIZE, uiBuffSize,9,uiDestDMACFG, pMUTWrite, uiDestMSIZE, uiBuffSize);
		WAIT_FOR_DMADONE(9);
		DISABLE_MDMA(8,9);

		//Increment the write pointer
		pMUTWrite+=uiBuffSize;

		//Perform DMA read accesses to transfer data from the memory location under test and to the dest buffer
		MDMA_CONFIG(8,uiSourceDMACFG, pMUTRead, uiSourceMSIZE, uiBuffSize,9,uiDestDMACFG, (void*)(((int)pDestBuff|0x28000000)), uiDestMSIZE, uiBuffSize);
		WAIT_FOR_DMADONE(9);
		DISABLE_MDMA(8,9);

		//Increment the read pointer
		pMUTRead+=uiBuffSize;

		//Re-initialize the source and dest buffer pointers
		pSrcBuff=uiSrcBuffAdd;
		pDestBuff=uiDestBuffAdd;

		uint64_t s1, d1;
		uint32_t* ps1; uint32_t* pd1; uint32_t* ps2; uint32_t* pd2;
		//Compare source and destination buffers for verification
		for(j=0;j<uiBuffSize*4;j++)
		{
			//If match does not occur, increment the failure count
			if(*pSrcBuff!=*pDestBuff)
			{
				uiFailCount++;
				s1=*pSrcBuff; d1=*pDestBuff;
				ps1=(uint32_t *)pSrcBuff; pd1=(uint32_t *)pDestBuff;
				ps2=ps1+1; pd2=pd1+1;
			}
			pSrcBuff++;
			pDestBuff++;
		}
	}
	if(uiFailCount==0)
	{
		printf("\nTest Passed...");
	}
	else
	{
		printf("\nTest Failed...");
	}
	return uiFailCount;
}

/**************************************************************************************************************************
	Function name	:  Memory_Sweep_Test
    Description		:  This function is a generic memory sweep function which can be used to test core and DMA accesses for different data patterns
	Arguments		:	Parameter					 |	Description		 							| Valid values
						uiMUTStartAdd				 |  Start address of the memory under test 		| unsigned int 32 bit
						uiCount						 |  Total number of words to be swept			| unsigned int 32 bit
	Return value	:   0=for no failure, non-zero= number of failures.
**************************************************************************************************************************/
uint32_t Memory_Sweep_Test(uint32_t uiMUTStartAdd, uint32_t uiCount)
{
	int i; int j;

	uint32_t uiFailCount=0;

	uint32_t uiMemType;


	int DFval=0, DSELval = 0, MSELval=0, CSELval = 0, SYSSELval, S0SELval, S1SELval;

	float CCLK, SYSCLK, DCLK, S0CLK, S1CLK;

	SPU_SecurePeripheral_AccessConfig(LSMDMA0_DDE8_ID,true,true);
	SPU_SecurePeripheral_AccessConfig(LSMDMA0_DDE9_ID,true,true);

	printf("\n\nWord size = 8 bits");
	printf("\n\nCore Test");
	//Perform core test first with different patterns
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, CORE_ACCESS, ALL_ZEROS, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, CORE_ACCESS, ALL_ONES, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, CORE_ACCESS, ALL_A, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, CORE_ACCESS, ALL_5, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, CORE_ACCESS, INCREMENTAL_VALUES, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, CORE_ACCESS, RANDOM_VALUES, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, CORE_ACCESS, ALL_BITS_TOGGLING, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);

	printf("\n\nDMA Test");
	//Then perform DMA accesses with different patterns
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, DMA_ACCESS, ALL_ZEROS, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, DMA_ACCESS, ALL_ONES, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, DMA_ACCESS, ALL_A, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, DMA_ACCESS, ALL_5, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, DMA_ACCESS, INCREMENTAL_VALUES, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, DMA_ACCESS, RANDOM_VALUES, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_8Bits((uint8_t*)uiMUTStartAdd, uiCount, DMA_ACCESS, ALL_BITS_TOGGLING, (uint8_t*)uiSrcBuff, (uint8_t*)uiDestBuff, 256);

	printf("\n\nWord size = 16 bits");
	printf("\n\nCore Test");
	//Perform core test first with different patterns
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, CORE_ACCESS, ALL_ZEROS, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, CORE_ACCESS, ALL_ONES, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, CORE_ACCESS, ALL_A, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, CORE_ACCESS, ALL_5, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, CORE_ACCESS, INCREMENTAL_VALUES, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, CORE_ACCESS, RANDOM_VALUES, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, CORE_ACCESS, ALL_BITS_TOGGLING, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);

	printf("\n\nDMA Test");
	//Then perform DMA accesses with different patterns
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, DMA_ACCESS, ALL_ZEROS, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, DMA_ACCESS, ALL_ONES, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, DMA_ACCESS, ALL_A, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, DMA_ACCESS, ALL_5, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, DMA_ACCESS, INCREMENTAL_VALUES, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, DMA_ACCESS, RANDOM_VALUES, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_16Bits((uint16_t*)uiMUTStartAdd, uiCount/2, DMA_ACCESS, ALL_BITS_TOGGLING, (uint16_t*)uiSrcBuff, (uint16_t*)uiDestBuff, 256);

	printf("\n\nWord size = 32 bits");
	printf("\n\nCore Test");
	//Perform core test first with different patterns
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, CORE_ACCESS, ALL_ZEROS, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, CORE_ACCESS, ALL_ONES, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, CORE_ACCESS, ALL_A, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, CORE_ACCESS, ALL_5, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, CORE_ACCESS, INCREMENTAL_VALUES, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, CORE_ACCESS, RANDOM_VALUES, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, CORE_ACCESS, ALL_BITS_TOGGLING, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);

	printf("\n\nDMA Test");
	//Then perform DMA accesses with different patterns
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, DMA_ACCESS, ALL_ZEROS, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, DMA_ACCESS, ALL_ONES, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, DMA_ACCESS, ALL_A, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, DMA_ACCESS, ALL_5, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, DMA_ACCESS, INCREMENTAL_VALUES, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, DMA_ACCESS, RANDOM_VALUES, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_32Bits((uint32_t*)uiMUTStartAdd, uiCount/4, DMA_ACCESS, ALL_BITS_TOGGLING, (uint32_t*)uiSrcBuff, (uint32_t*)uiDestBuff, 256);

	printf("\n\nWord size = 64 bits");
	printf("\n\nCore Test");
	//Perform core test first with different patterns
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, CORE_ACCESS, ALL_ZEROS, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, CORE_ACCESS, ALL_ONES, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, CORE_ACCESS, ALL_A, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, CORE_ACCESS, ALL_5, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, CORE_ACCESS, INCREMENTAL_VALUES, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, CORE_ACCESS, RANDOM_VALUES, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, CORE_ACCESS, ALL_BITS_TOGGLING, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);

	printf("\n\nDMA Test");
	//Then perform DMA accesses with different patterns
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, DMA_ACCESS, ALL_ZEROS, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, DMA_ACCESS, ALL_ONES, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, DMA_ACCESS, ALL_A, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, DMA_ACCESS, ALL_5, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, DMA_ACCESS, INCREMENTAL_VALUES, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, DMA_ACCESS, RANDOM_VALUES, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_64Bits((uint64_t*)uiMUTStartAdd, uiCount/8, DMA_ACCESS, ALL_BITS_TOGGLING, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);


	printf("\n\nWord size = 32 bytes");
	printf("\n\nDMA Test");
	//Then perform DMA accesses with different patterns
	uiFailCount+=Memory_Sweep_Test_MSIZE32((uint64_t*)uiMUTStartAdd, uiCount/32, DMA_ACCESS, ALL_ZEROS, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_MSIZE32((uint64_t*)uiMUTStartAdd, uiCount/32, DMA_ACCESS, ALL_ONES, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_MSIZE32((uint64_t*)uiMUTStartAdd, uiCount/32, DMA_ACCESS, ALL_A, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_MSIZE32((uint64_t*)uiMUTStartAdd, uiCount/32, DMA_ACCESS, ALL_5, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_MSIZE32((uint64_t*)uiMUTStartAdd, uiCount/32, DMA_ACCESS, INCREMENTAL_VALUES, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_MSIZE32((uint64_t*)uiMUTStartAdd, uiCount/32, DMA_ACCESS, RANDOM_VALUES, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);
	uiFailCount+=Memory_Sweep_Test_MSIZE32((uint64_t*)uiMUTStartAdd, uiCount/32, DMA_ACCESS, ALL_BITS_TOGGLING, (uint64_t*)uiSrcBuff, (uint64_t*)uiDestBuff, 256);

	return uiFailCount;
}

void SPU_SecurePeripheral_AccessConfig(int iPeripheralID, bool bMaster, bool bSlave )
{
	volatile uint32_t *pRegSecureP = (volatile uint32_t *)(SECURE_PERIPHERAL_BASE_ADDRESS + (iPeripheralID*4));

	int iSecurePvalue = 0;

	if(bMaster == true)
		iSecurePvalue |= SECUREP_MSEC_EN;
	else
		iSecurePvalue &= SECUREP_MSEC_DIS;

	if(bSlave == true)
		iSecurePvalue |= SECUREP_SSEC_EN;
	else
		iSecurePvalue &= SECUREP_SSEC_DIS;

	*pRegSecureP = iSecurePvalue;
}
